@@ -175,7 +175,7 @@ class Onglets(wx.Notebook):
 
         if(shortname == "wineversion"):
             self.addBitmap = wx.Image( Variables.playonlinux_env+"/resources/images/icones/list-add.png", wx.BITMAP_TYPE_ANY).ConvertToBitmap()
-            if(os.environ["POL_OS"] == "Linux"):
+            if(os.environ["POL_OS"] == "Linux" or os.environ["POL_OS"] == "FreeBSD"):
                 self.general_elements["wineversion_button"] = wx.BitmapButton(self.panelGeneral,601, pos=(527,19+num*40),size=(21,21),bitmap=self.addBitmap)
             if(os.environ["POL_OS"] == "Mac"):
                 self.general_elements["wineversion_button"] = wx.BitmapButton(self.panelGeneral,601, pos=(522,15+num*40),size=(21,21),bitmap=self.addBitmap)
@@ -577,11 +577,21 @@ class Onglets(wx.Notebook):
         self.AddPage(self.panelMisc, nom)
 
     def assign(self, event):
+        old_version = playonlinux.GetSettings('VERSION',self.s_prefix)
+        if old_version == '':
+            old_version = 'System'
         version = self.general_elements["wineversion"].GetValue()
-        if(version != 'System'):
-            playonlinux.SetSettings('VERSION',version,self.s_prefix)
-        else:
-            playonlinux.DeleteSettings('VERSION',self.s_prefix)
+        if version != old_version:
+            if (wx.YES == wx.MessageBox(_("Warning:\n\nAny program still running in this virtual drive will be terminated before Wine version is changed.\nAre you sure you want to continue?"), os.environ["APPLICATION_TITLE"], style = wx.YES_NO | wx.ICON_QUESTION)):
+                self.evt_killall(event)
+                if version != 'System':
+                    playonlinux.SetSettings('VERSION',version,self.s_prefix)
+                else:
+                    playonlinux.DeleteSettings('VERSION',self.s_prefix)
+            else:
+                version = old_version
+                self.general_elements["wineversion"].SetValue(old_version)
+
     def assignPrefix(self, event):
         if(wx.YES == wx.MessageBox(_("Be careful!\nIf you change "+self.s_title+"'s virtual drive, you are likekely to break it.\nDo this only if you know what you are doing.\n\nAre you sure you want to continue?"),os.environ["APPLICATION_TITLE"] ,style=wx.YES_NO | wx.ICON_QUESTION)):
             drive = self.general_elements["wineprefix"].GetValue()
@@ -641,7 +651,7 @@ class Onglets(wx.Notebook):
 
 class MainWindow(wx.Frame):
     def __init__(self,parent,id,title,shortcut, isPrefix = False):
-        wx.Frame.__init__(self, parent, -1, title, size = (800, 450), style = wx.CLOSE_BOX | wx.CAPTION | wx.MINIMIZE_BOX)
+        wx.Frame.__init__(self, parent, -1, title, size = (800, 450+Variables.windows_add_size), style = wx.CLOSE_BOX | wx.CAPTION | wx.MINIMIZE_BOX)
         self.SetIcon(wx.Icon(Variables.playonlinux_env+"/etc/playonlinux.png", wx.BITMAP_TYPE_ANY))
         self.SetTitle(_('{0} configuration').format(os.environ["APPLICATION_TITLE"]))
         #self.panelFenp = wx.Panel(self, -1)
@@ -669,8 +679,12 @@ class MainWindow(wx.Frame):
         self.list_game = wx.TreeCtrl(self.splitter_list, 900, size = wx.DefaultSize, style=wx.TR_HIDE_ROOT)
         self.control_game = wx.Panel(self.splitter_list, -1)
 
-        self.AddPrefix = wx.Button(self.control_game, 1001, _("New"), pos=(0,0),size=(95+10*Variables.windows_add_playonmac,30))
-        self.DelPrefix = wx.Button(self.control_game, 1002, _("Remove"), pos=(100,0), size=(95+10*Variables.windows_add_playonmac,30))
+        if(os.environ["POL_OS"] == "Mac"):
+            self.AddPrefix = wx.Button(self.control_game, 1001, _("New"), pos=(0,-8),size=(93,30))
+            self.DelPrefix = wx.Button(self.control_game, 1002, _("Remove"), pos=(98,-8), size=(93,30))
+        else:
+            self.AddPrefix = wx.Button(self.control_game, 1001, _("New"), pos=(0,0),size=(95,30))
+            self.DelPrefix = wx.Button(self.control_game, 1002, _("Remove"), pos=(100,0), size=(95,30))
 
         wx.EVT_BUTTON(self, 1001, self.NewPrefix)
         wx.EVT_BUTTON(self, 1002, self.DeletePrefix)
@@ -756,7 +770,7 @@ class MainWindow(wx.Frame):
                 for dir in dirs:
                     fullpath = os.path.join(dirname, dir)
                     # To speed up the process, only modify metadata when necessary
-                    attr = os.stat(fullpath)
+                    attr = os.lstat(fullpath)
                     if attr.st_mode & needed_dir_rights != needed_dir_rights:
                         print "%s rights need fixing" % fullpath
                         os.chmod(fullpath, needed_dir_rights)
@@ -804,14 +818,19 @@ class MainWindow(wx.Frame):
         self.onglets.changing_selection = True
         if(isPrefix == True):
             self.onglets.s_isPrefix = True
-            if(self.current_sel == "default"):
+            try:
+                if(self.current_sel == "default"):
+                    self.splitter.Unsplit()
+                    self.splitter.SplitVertically(self.splitter_list,self.panelEmpty)
+                    self.splitter.SetSashPosition(200)
+                else:
+                    self.splitter.Unsplit()
+                    self.splitter.SplitVertically(self.splitter_list,self.onglets)
+                    self.splitter.SetSashPosition(200)
+            except AttributeError:
                 self.splitter.Unsplit()
                 self.splitter.SplitVertically(self.splitter_list,self.panelEmpty)
                 self.splitter.SetSashPosition(200)
-            else:
-                self.splitter.Unsplit()
-                self.splitter.SplitVertically(self.splitter_list,self.onglets)
-                self.splitter.SetSashPosition(200)
         else:
             self.splitter.Unsplit()
             self.splitter.SplitVertically(self.splitter_list,self.onglets)
