@@ -72,7 +72,7 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
         self.small_x = 520 - self.small_image.GetWidth()
 
         if(Arg2 == "None"):
-            if(os.environ["POL_OS"] == "Linux"):
+            if(os.environ["POL_OS"] != "Mac"):
                 self.big_image = wx.Bitmap(Variables.playonlinux_env+"/resources/images/setups/default/playonlinux.jpg")
             else:
                 self.big_image = wx.Bitmap(Variables.playonlinux_env+"/resources/images/setups/default/playonmac.jpg")
@@ -136,7 +136,7 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
         # Buttons
         
 
-        if(os.environ["POL_OS"] == "Linux"):
+        if(os.environ["POL_OS"] != "Mac"):
             self.CancelButton = wx.Button(self.footer, wx.ID_CANCEL, _("Cancel"), pos=(430,0),size=(85,37))
             self.NextButton = wx.Button(self.footer, wx.ID_FORWARD, _("Next"), pos=(340,0),size=(85,37))
         else:
@@ -153,8 +153,13 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
         self.InfoScript.Bind(wx.EVT_LEFT_DOWN, self.InfoClick)
         self.InfoScript.SetCursor(wx.StockCursor(wx.CURSOR_HAND))
 
-        self.NoButton = wx.Button(self.footer, wx.ID_NO, _("No"), pos=(430,0),size=(85,37))
-        self.YesButton = wx.Button(self.footer, wx.ID_YES, _("Yes"), pos=(340,0), size=(85,37))
+        if(os.environ["POL_OS"] != "Mac"):
+            self.NoButton = wx.Button(self.footer, wx.ID_NO, _("No"), pos=(430,0),size=(85,37))
+            self.YesButton = wx.Button(self.footer, wx.ID_YES, _("Yes"), pos=(340,0), size=(85,37))
+        else:
+            self.NoButton = wx.Button(self.footer, wx.ID_NO, _("No"), pos=(420,-3),size=(85,37))
+            self.YesButton = wx.Button(self.footer, wx.ID_YES, _("Yes"), pos=(330,-3), size=(85,37))           
+        
         self.browse = wx.Button(self.panel, 103, _("Browse"), size=(130,40))
         self.browse_text = wx.StaticText(self.panel, -1, "")
         self.browse_image = wx.StaticBitmap(self.panel, -1, wx.Bitmap(os.environ['PLAYONLINUX']+"/etc/playonlinux.png"))
@@ -276,17 +281,26 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
         ## If the setup window is downloading a file, it is a good occasion to update the progresbar
         if(self.Timer_downloading == True):
             if(self.downloader.taille_bloc != 0):
-                self.nb_blocs_max = self.downloader.taille_fichier / self.downloader.taille_bloc
-                self.gauge.SetRange(self.nb_blocs_max)
-                self.gauge.SetValue(self.downloader.nb_blocs)
+                downloaded = self.downloader.nb_blocs * self.downloader.taille_bloc
+                octetsLoadedB = downloaded / 1048576.0
+                octetsLoadedN = str(round(octetsLoadedB, 1))
 
-                self.tailleFichierB = float(self.downloader.taille_fichier / 1048576.0)
-                self.octetsLoadedB = float((self.downloader.nb_blocs * self.downloader.taille_bloc) / 1048576.0)
-                self.octetsLoadedN = round(self.octetsLoadedB, 1)
-                self.tailleFichierN = round(self.tailleFichierB, 1)
+                # may be -1 on older FTP servers which do not return a file size in response to a retrieval request
+                if self.downloader.taille_fichier >= 0:
+                    self.gauge.SetRange(self.downloader.taille_fichier)
+                
+                    try:
+                        self.gauge.SetValue(downloaded)
+                    except wx._core.PyAssertionError:
+                        pass
+                    
+                    tailleFichierB = self.downloader.taille_fichier / 1048576.0
+                    tailleFichierN = str(round(tailleFichierB, 1))
+                else:
+                    tailleFichierN = "?"
 
-                self.estimation_txt = str(self.octetsLoadedN) + " "+_("of")+" " + str(self.tailleFichierN) + " "+_("MB downloaded")
-                self.txtEstimation.SetLabel(self.estimation_txt)
+                estimation_txt = octetsLoadedN + " "+_("of")+" " + tailleFichierN + " "+_("MB downloaded")
+                self.txtEstimation.SetLabel(estimation_txt)
 
             if(self.downloader.finished == True):
                 if(self.downloader.failed == True):
@@ -339,13 +353,19 @@ class POL_SetupFrame(wx.Frame): #fenêtre principale
             os.system("xdg-open "+url+" &")
 
 
-    def POL_SetupWindow_textbox(self, message, title, value):
+    def POL_SetupWindow_textbox(self, message, title, value, maxlength=0):
+        try:
+            maxlength = int(maxlength)
+        except ValueError:
+            maxlength = 0
+
         self.Destroy_all()
         self.DrawDefault(message, title)
 
         self.space = message.count("\\n")+1
 
         self.champ.SetPosition((20,85+self.space*16))
+        self.champ.SetMaxLength(maxlength if maxlength > 0 else 0)
         self.champ.SetValue(value)
         self.champ.Show()
 
