@@ -16,7 +16,7 @@ except :
 os.environ["POL_PORT"] = "0"
 os.environ["PLAYONLINUX"] = os.path.realpath(os.path.realpath(__file__)+"/../../../")
 os.environ["SITE"] = "http://repository.playonlinux.com"
-os.environ["VERSION"] = "4.2.2"
+os.environ["VERSION"] = "4.2.3"
 os.environ["POL_ID"] = str(random.randint(1,100000000))
 os.environ["WINE_SITE"] = "http://www.playonlinux.com/wine/binaries"
 os.environ["GECKO_SITE"] = "http://www.playonlinux.com/wine/gecko"
@@ -54,6 +54,20 @@ if (os.environ["POL_OS"] == "Linux"):
     else:
         os.environ["POL_WGET"] = "wget --prefer-family=IPv4 -q"
 
+if (os.environ["POL_OS"] == "FreeBSD"):
+    os.environ["REPERTOIRE"] = os.environ["HOME"]+"/.PlayOnBSD/"
+    os.environ["APPLICATION_TITLE"] = "PlayOnBSD"
+    os.environ["POL_DNS"] = "playonlinux.com"
+    windows_add_size = 0;
+    windows_add_playonmac = 0;
+    widget_borders = wx.RAISED_BORDER
+    os_name = "freebsd"
+    if not os.path.exists("/proc/net/if_inet6"):
+        os.environ["POL_WGET"] = "wget -q"
+    else:
+        os.environ["POL_WGET"] = "wget --prefer-family=IPv4 -q"
+        
+        
 os.environ["POL_CURL"] = "curl"
 
 archi = string.split(os.environ["MACHTYPE"],"-")
@@ -98,15 +112,20 @@ if (os.environ["POL_OS"] == "Mac"):
     os.environ["DYLD_LIBRARY_PATH"] = os.environ["PLAYONLINUX"]+"/../unix/tools/lib/dyld:" + os.environ["PLAYONLINUX"]+"/../unix/image_magick/lib:"+ os.environ["DYLD_LIBRARY_PATH"]
 else:
     # Debian maintainer decided for some reason not to let wineserver binary into PATH...
-    for winepath in ('/usr/lib/wine', '/usr/lib/wine-unstable', \
-                     '/usr/lib/i386-linux-gnu/wine', '/usr/lib/i386-linux-gnu/wine-unstable', \
-                     '/usr/lib32/wine', '/usr/lib32/wine-unstable'):
+    for winepath in ('/usr/lib/i386-linux-gnu/wine/bin', '/usr/lib/i386-linux-gnu/wine-unstable/bin', \
+                     '/usr/lib32/wine', '/usr/lib32/wine-unstable', \
+                     '/usr/lib/wine', '/usr/lib/wine-unstable'):
         if os.path.exists('%s/wineserver' % (winepath,)):
             os.environ["PATH"] += ':%s' % (winepath,)
             break
 
 os.environ["PATH_ORIGIN"] = os.environ["PATH"]
 os.environ["LD_PATH_ORIGIN"] = os.environ["LD_LIBRARY_PATH"]
+try:
+    os.environ["LD_32_PATH_ORIGIN"] = os.environ["LD_32_LIBRARY_PATH"]
+except KeyError:
+    os.environ["LD_32_PATH_ORIGIN"] = ""
+    
 os.environ["DYLDPATH_ORIGIN"] = os.environ["DYLD_LIBRARY_PATH"]
 
 playonlinux_env = os.environ["PLAYONLINUX"]
