@@ -27,7 +27,7 @@ except :
     print "ERROR ! Please define POL_OS environment var first."
     os._exit(1)
 
-if(os.environ["POL_OS"] == "Linux"):
+if(os.environ["POL_OS"] != "Mac"):
     import wxversion
     wxversion.ensureMinimal('2.8')
 
@@ -35,7 +35,6 @@ import wx, wx.aui
 import lib.lng as lng
 import lib.playonlinux as playonlinux, lib.Variables as Variables
 import guiv3 as gui, install, options, wine_versions as wver, sp, configure, threading, debug, gui_server
-import irc as ircgui
 
 # This thread manage updates
 class POLWeb(threading.Thread):
@@ -62,6 +61,8 @@ class POLWeb(threading.Thread):
     def LastVersion(self):
         if(os.environ["POL_OS"] == "Mac"):
             fichier_online="version_mac"
+        elif(os.environ["POL_OS"] == "FreeBSD"):
+            fichier_online="version_freebsd"
         else:
             fichier_online="version2"
         return os.popen(os.environ["POL_WGET"]+' "'+os.environ["SITE"]+'/'+fichier_online+'.php?v='+os.environ["VERSION"]+'" -T 30 -O-','r').read()
@@ -108,6 +109,51 @@ class POLWeb(threading.Thread):
                 self.real_check()
             time.sleep(1)
 
+class PanelManager(wx.aui.AuiManager):
+
+    def __init__(self, frame):
+        wx.aui.AuiManager.__init__(self, frame)
+        self.startPerspective = self.SavePerspective()
+        
+        
+    def _getPerspectiveName(self):
+        name = self.SavePerspective().split("=")
+        name = name[1].split(";")
+        name = name[0]
+        return name 
+
+    def getPerspective(self):
+        return self.SavePerspective().replace(self._getPerspectiveName(),"PERSPECTIVE_NAME")
+        
+    def savePosition(self):
+        playonlinux.SetSettings("PANEL_PERSPECTIVE", self.getPerspective())
+        
+    def restorePosition(self):
+        self.startPerspective = self.SavePerspective()
+       
+        self.Update()
+        
+        try:
+            setting = playonlinux.GetSettings("PANEL_PERSPECTIVE")
+            if(setting.count("Actions") < 2 or setting.count("dock_size") < 2 or not "PERSPECTIVE_NAME" in setting):
+                self.LoadPerspective(self.startPerspective)
+            else:
+                setting = setting.replace("PERSPECTIVE_NAME",self._getPerspectiveName())
+                if(setting != ""):
+                     self.LoadPerspective(setting)
+        
+        except wx._core.PyAssertionError:
+            self.LoadPerspective(self.startPerspective)
+        
+        
+        self.Update()
+         
+    def AddPane(self, data, settings):
+        wx.aui.AuiManager.AddPane(self, data, settings)
+        
+    def Destroy(self):
+        self.savePosition()
+        
 class MainWindow(wx.Frame):
     def __init__(self,parent,id,title):
 
@@ -136,7 +182,7 @@ class MainWindow(wx.Frame):
             self.windowHeight = int(playonlinux.GetSettings("MAINWINDOW_HEIGHT"))
             self.SetSize((self.windowWidth,self.windowHeight))
         except:
-            self.windowWidth = 450
+            self.windowWidth = 500
             self.windowHeight = 450
 
         # Window position
@@ -177,15 +223,14 @@ class MainWindow(wx.Frame):
         self.list_game.SetSpacing(0);
         self.list_game.SetIndent(5);
         self.list_game.SetImageList(self.images)
-
-        self._mgr = wx.aui.AuiManager(self)
         self.menu_gauche = wx.Panel(self,-1)
 
-
-
+        self._mgr = PanelManager(self)
         self._mgr.AddPane(self.list_game, wx.CENTER)
-
-
+        self._mgr.AddPane(self.menu_gauche, wx.aui.AuiPaneInfo().Name('Actions').Caption('Actions').Left().BestSize((200,400)).Floatable(True).CloseButton(False).TopDockable(False).BottomDockable(False))
+        
+         
+        
         self.filemenu = wx.Menu()
         ### On MacOS X, preference is always on the main menu
         if(os.environ["POL_OS"] == "Mac"):
@@ -217,56 +262,38 @@ class MainWindow(wx.Frame):
 
         self.expertmenu = wx.Menu()
 
-        self.winever_item = wx.MenuItem(self.expertmenu, 107, _("Manage Wine versions"))
-        self.winever_item.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/resources/images/menu/wine.png"))
-        self.expertmenu.AppendItem(self.winever_item)
+        self.expertmenu.Append(107, _("Manage Wine versions"))
+
 
         if(os.environ["POL_OS"] == "Mac"):
             self.expertmenu.AppendSeparator()
-            self.pccd_item = wx.MenuItem(self.expertmenu, 113, _("Read a PC CD-Rom"))
-            self.pccd_item.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/resources/images/menu/cdrom.png"))
-            self.expertmenu.AppendItem(self.pccd_item)
+            self.expertmenu.Append(113, _("Read a PC CD-Rom"))
 
         self.expertmenu.AppendSeparator()
 
-        self.run_item = wx.MenuItem(self.expertmenu, 108, _("Run a local script"))
-        self.run_item.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/resources/images/menu/run.png"))
-        self.expertmenu.AppendItem(self.run_item)
-
-        self.wineserv_item = wx.MenuItem(self.expertmenu, 115, _('Close all {0} software').format(os.environ["APPLICATION_TITLE"]))
-        self.wineserv_item.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/resources/images/menu/wineserver.png"))
-        self.expertmenu.AppendItem(self.wineserv_item)
-
-        self.polshell_item = wx.MenuItem(self.expertmenu, 109, _('{0} console').format(os.environ["APPLICATION_TITLE"]))
-        self.polshell_item.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/resources/images/menu/polshell.png"))
-        self.expertmenu.AppendItem(self.polshell_item)
-
+        self.expertmenu.Append(108, _("Run a local script"))
+        self.expertmenu.Append(109, _("{0} console").format(os.environ["APPLICATION_TITLE"]))
+        
+        self.expertmenu.Append(115, _('Close all {0} software').format(os.environ["APPLICATION_TITLE"]))
         self.expertmenu.AppendSeparator()
 
-        self.pol_online = wx.MenuItem(self.expertmenu, 112, os.environ["APPLICATION_TITLE"]+" online")
-        self.pol_online.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/resources/images/menu/playonlinux_online.png"))
-        self.expertmenu.AppendItem(self.pol_online)
-
-        self.chat_item = wx.MenuItem(self.expertmenu, 111, _("{0} messenger").format(os.environ["APPLICATION_TITLE"]))
-        self.chat_item.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/resources/images/menu/people.png"))
-        self.expertmenu.AppendItem(self.chat_item)
-
-        self.bug_item = wx.MenuItem(self.expertmenu, 110, _("{0} debugger").format(os.environ["APPLICATION_TITLE"]))
-        self.bug_item.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/resources/images/menu/bug.png"))
-        self.expertmenu.AppendItem(self.bug_item)
+        self.expertmenu.Append(110, _("{0} debugger").format(os.environ["APPLICATION_TITLE"]))
 
 
         self.optionmenu = wx.Menu()
 
 
-        self.option_item = wx.MenuItem(self.expertmenu, 211, _("Internet"))
-        self.option_item.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/internet-web-browser.png"))
-        self.optionmenu.AppendItem(self.option_item)
+        self.optionmenu.Append(221, _("Internet"))
+        self.optionmenu.Append(212, _("File associations"))
+        self.optionmenu.Append(214, _("Plugin manager"))
 
-        self.option_item = wx.MenuItem(self.expertmenu, 212, _("File associations"))
-        self.option_item.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/resources/images/menu/extensions.png"))
-        self.optionmenu.AppendItem(self.option_item)
 
+        self.supportmenu = wx.Menu()
+        self.supportmenu.Append(400, _("Supported software"))
+        self.supportmenu.Append(401, _("News"))
+        self.supportmenu.Append(402, _("Documentation"))
+        self.supportmenu.Append(403, _("Forums"))
+        self.supportmenu.Append(404, _("Bugs"))
 
 
         self.help_menu = wx.Menu()
@@ -299,13 +326,13 @@ class MainWindow(wx.Frame):
         if(self.j > 0):
             self.pluginsmenu.AppendSeparator()
 
-        self.option_item_p = wx.MenuItem(self.expertmenu, 214, _("Plugin manager"))
-        self.option_item_p.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/package-x-generic.png"))
-        self.pluginsmenu.AppendItem(self.option_item_p)
 
-        self.option_item = wx.MenuItem(self.expertmenu, 214, _("Plugin manager"))
-        self.option_item.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/package-x-generic.png"))
-        self.optionmenu.AppendItem(self.option_item)
+
+
+        self.option_item_p = wx.MenuItem(self.pluginsmenu, 214, _("Plugin manager"))
+        self.option_item_p.SetBitmap(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/package-x-generic.png"))
+        
+        self.pluginsmenu.AppendItem(self.option_item_p)
 
 
         self.last_string = ""
@@ -333,6 +360,7 @@ class MainWindow(wx.Frame):
         self.menubar.Append(self.expertmenu, _("Tools"))
         self.menubar.Append(self.optionmenu, _("Settings"))
         self.menubar.Append(self.pluginsmenu, _("Plugins"))
+        self.menubar.Append(self.supportmenu, _("Support"))
         self.menubar.Append(self.help_menu, "&Help")
 
         #self.menubar.Append(self.help_menu, _("About"))
@@ -384,7 +412,6 @@ class MainWindow(wx.Frame):
         wx.EVT_MENU(self, 502,  self.iconDisplay)
         wx.EVT_MENU(self, 503,  self.iconDisplay)
         wx.EVT_MENU(self, 504,  self.iconDisplay)
-        wx.EVT_MENU(self, 505,  self.displayMen)
 
         # Expert
         wx.EVT_MENU(self, 101,  self.Reload)
@@ -392,7 +419,6 @@ class MainWindow(wx.Frame):
         wx.EVT_MENU(self, 108,  self.Executer)
         wx.EVT_MENU(self, 109,  self.PolShell)
         wx.EVT_MENU(self, 110,  self.BugReport)
-        wx.EVT_MENU(self, 111,  self.OpenIrc)
         wx.EVT_MENU(self, 112,  self.POLOnline)
         wx.EVT_MENU(self, 113,  self.PCCd)
         wx.EVT_MENU(self, 115,  self.killall)
@@ -414,7 +440,13 @@ class MainWindow(wx.Frame):
         wx.EVT_TREE_ITEM_ACTIVATED(self, 105, self.Run)
         wx.EVT_TREE_SEL_CHANGED(self, 105, self.Select)
 
-
+        # Support
+        wx.EVT_MENU(self, 400,  self.runSupport)
+        wx.EVT_MENU(self, 401,  self.runSupport)
+        wx.EVT_MENU(self, 402,  self.runSupport)
+        wx.EVT_MENU(self, 403,  self.runSupport)
+        wx.EVT_MENU(self, 404,  self.runSupport)
+        
         # PlayOnLinux main timer
         self.timer = wx.Timer(self, 1)
         self.Bind(wx.EVT_TIMER, self.TimerAction, self.timer)
@@ -439,8 +471,7 @@ class MainWindow(wx.Frame):
         wx.EVT_MENU(self, 235, self.RKill)
         wx.EVT_MENU(self, 236, self.ReadMe)
         self.Bind(wx.EVT_SIZE, self.ResizeWindow)
-
-        self.MgrAddPage()
+        self._mgr.restorePosition()   
 
     def ResizeWindow(self, e):
         self.UpdateGaugePos()
@@ -471,7 +502,6 @@ class MainWindow(wx.Frame):
             self.SetupWindowTimer_delay = time
 
     def SetupWindowAction(self, event):
-        
         if(self.windowOpened == 0):
             self.SetupWindow_TimerRestart(100)
         else:
@@ -491,36 +521,6 @@ class MainWindow(wx.Frame):
             self.Reload(self)
             self.Timer_LastShortcutList = currentShortcuts
             self.Timer_LastIconList = currentIcons
-            
-    def MgrAddPage(self):
-        try:
-            self.LoadSize = int(playonlinux.GetSettings("PANEL_SIZE"))
-        except:
-            self.LoadSize = 150
-
-        try:
-            self.LoadPosition = playonlinux.GetSettings("PANEL_POSITION")
-        except:
-            self.LoadPosition = "LEFT"
-
-        if(self.LoadSize < 20):
-            self.LoadSize = 20
-        if(self.LoadSize > 1000):
-            self.LoadSize = 1000
-
-
-        if(self.LoadPosition == "LEFT"):
-            self._mgr.AddPane(self.menu_gauche, wx.aui.AuiPaneInfo().Name('Actions').Caption('Actions').Left().BestSize((self.LoadSize,400)).Floatable(True).CloseButton(False).TopDockable(False).BottomDockable(False))
-        else:
-            self._mgr.AddPane(self.menu_gauche, wx.aui.AuiPaneInfo().Name('Actions').Caption('Actions').Right().BestSize((self.LoadSize,400)).Floatable(True).CloseButton(False).TopDockable(False).BottomDockable(False))
-        self.menu_gauche.Show()
-
-        self._mgr.Update()
-
-    def displayMen(self, event):
-        playonlinux.SetSettings("PANEL_POSITION","LEFT")
-        if(self.panDisplay.IsChecked()):
-            self.MgrAddPage()
 
     def StatusRead(self):
         self.sb.SetStatusText(self.updater.sendToStatusBarStr, 0)
@@ -627,6 +627,22 @@ class MainWindow(wx.Frame):
             subprocess.Popen(["bash", Variables.playonlinux_rep+"/plugins/"+plugin+"/scripts/menu", game_exec])
         except :
             pass
+            
+    def runSupport(self, event):
+        urlId = event.GetId()-400
+        urlPrefix = "http://www."+os.environ["POL_DNS"]+"/en"
+        if(urlId == 0):
+            url = urlPrefix+"/supported_apps.html"
+        if(urlId == 1):
+            url = urlPrefix+"/news.html"
+        if(urlId == 2):
+            url = urlPrefix+"/documentation.html"
+        if(urlId == 3):
+            url = urlPrefix+"/forums.html"
+        if(urlId == 4):
+            url = urlPrefix+"/bugs.html"
+        
+        playonlinux.POL_Open(url)
 
     def iconDisplay(self, event):
         iconEvent=event.GetId()
@@ -649,11 +665,6 @@ class MainWindow(wx.Frame):
 
         self.Reload(self)
 
-    def OpenIrc(self, event):
-        self.irc = ircgui.IrcClient(self)
-        self.irc.Center(wx.BOTH)
-        self.irc.Show(True)
-
     def UpdateInstructions(self, event):
         if(os.environ["POL_OS"] == "Mac"):
             webbrowser.open("http://www.playonmac.com/en/download.html")
@@ -721,8 +732,8 @@ class MainWindow(wx.Frame):
         self.menuGaucheAddLink("pol_prgm_install", _("Install a program"), i,Variables.playonlinux_env+"/resources/images/menu/add.png",self.InstallMenu)
         i+=1
         self.menuGaucheAddLink("pol_prgm_settings", _("Settings"), i,Variables.playonlinux_env+"/resources/images/menu/settings.png",self.Options)
-        i+=1
-        self.menuGaucheAddLink("pol_prgm_messenger", _("Messenger"), i,Variables.playonlinux_env+"/resources/images/menu/people.png",self.OpenIrc)
+
+
         if(os.path.exists(os.environ["PLAYONLINUX"]+"/.git/")):
             i+=1
             self.menuGaucheAddLink("pol_git", _("Update GIT"), i,Variables.playonlinux_env+"/resources/images/menu/update_git.png",self.UpdateGIT)
@@ -751,8 +762,6 @@ class MainWindow(wx.Frame):
             if(os.path.exists(os.environ["POL_USER_ROOT"]+"/configurations/manuals/"+shortcut)):
                 i+=1
                 self.menuGaucheAddLink("pol_prgm_readme", _("Read the manual"), i,Variables.playonlinux_env+"/resources/images/menu/manual.png",self.ReadMe)
-            i+=1
-            self.menuGaucheAddLink("pol_prgm_polvaultsave", _("Save"), i,Variables.playonlinux_env+"/resources/images/menu/polvault.png",self.PolVaultSaveGame)
 
             i+=1
             self.menuGaucheAddLink("pol_prgm_uninstall", _("Uninstall"), i,Variables.playonlinux_env+"/resources/images/menu/window-close.png",self.UninstallGame)
@@ -772,12 +781,6 @@ class MainWindow(wx.Frame):
 
             icon = os.environ["POL_USER_ROOT"]+"/icones/full_size/"+shortcut
 
-            self.perspective = self._mgr.SavePerspective().split("|")
-            self.perspective = self.perspective[len(self.perspective) - 2].split("=")
-
-            left_pos = (int(self.perspective[1]) - 50)/2
-            if(left_pos <= 0):
-                left_pos = (200-48)/2
 
             if(os.path.exists(icon)):
                 try:
@@ -1056,32 +1059,15 @@ class MainWindow(wx.Frame):
             playonlinux.SetSettings("MAINWINDOW_HEIGHT",str(self.SizeToSave[1]-Variables.windows_add_playonmac*56))
             playonlinux.SetSettings("MAINWINDOW_X",str(self.PositionToSave[0]))
             playonlinux.SetSettings("MAINWINDOW_Y",str(self.PositionToSave[1]))
-            self._mgr.UnInit()
-            # I know, that's very ugly, but I have no choice for the moment
-            self.perspective = self._mgr.SavePerspective().split("|")
-            self.perspective = self.perspective[len(self.perspective) - 2].split("=")
-
-            self.DockType = self.perspective[0]
-            self.mySize = 200
-            self.myPosition = "LEFT"
-
-            if(self.DockType == "dock_size(4,0,0)"):
-                self.mySize = int(self.perspective[1]) - 2
-                self.myPosition = "LEFT"
-
-            if(self.DockType == "dock_size(2,0,1)" or self.DockType == "dock_size(2,0,0)" or "dock_size(2," in self.DockType):
-                self.mySize = int(self.perspective[1]) - 2
-                self.myPosition = "RIGHT"
-
-            playonlinux.SetSettings("PANEL_SIZE",str(self.mySize))
-            playonlinux.SetSettings("PANEL_POSITION",str(self.myPosition))
+           
+            self._mgr.Destroy()
 
             self.POLDie()
         return None
 
     def About(self, event):
         self.aboutBox = wx.AboutDialogInfo()
-        if(os.environ["POL_OS"] == "Linux"):
+        if(os.environ["POL_OS"] != "Mac"):
             self.aboutBox.SetIcon(wx.Icon(Variables.playonlinux_env+"/etc/playonlinux.png", wx.BITMAP_TYPE_ANY))
 
 
@@ -1230,7 +1216,7 @@ class PlayOnLinuxApp(wx.App):
         
         self.singleCheckFatal("gpg", package="GnuPG")
 
-        if(os.environ["DEBIAN_PACKAGE"] == "FALSE"):
+        if(os.environ["DEBIAN_PACKAGE"] == "FALSE" and os.environ["POL_OS"] != "Mac"):
             self.singleCheck("xterm")
         self.singleCheck("gettext.sh", package="gettext")  # gettext-base on Debian
         self.singleCheck("icotool", package="icoutils")
@@ -1238,7 +1224,9 @@ class PlayOnLinuxApp(wx.App):
         self.singleCheck("wine", package="Wine")
         self.singleCheck("unzip", package="InfoZIP")
         self.singleCheck("7z", package="P7ZIP full")  # p7zip-full on Debian
-
+        if(os.environ["POL_OS"] == "FreeBSD"):
+            self.singleCheck("gsed", package="GNU Sed")
+            
     def BringWindowToFront(self):
         try: # it's possible for this event to come when the frame is closed
             self.GetTopWindow().Raise()
@@ -1274,13 +1262,15 @@ class PlayOnLinuxApp(wx.App):
                 os.system("bash \"$PLAYONLINUX/bash/playonlinux-pkg\" -i \""+filename+"\" &")
         else:
             playonlinux.open_document(filename,file_extension.lower())
-
+ 
     def MacOpenURL(self, url):
-        if(os.environ["POL_OS"] == "Mac" and "playonlinux://" in url):
-            wx.MessageBox(_("You are trying to open a script design for {0}! It might not work as expected").format("PlayOnLinux"), os.environ["APPLICATION_TITLE"])
-        if(os.environ["POL_OS"] == "Linux" and "playonmac://" in url):
-            wx.MessageBox(_("You are trying to open a script design for {0}! It might not work as expected").format("PlayOnMac"), os.environ["APPLICATION_TITLE"])
-
+        if(os.environ["POL_OS"] == "Mac" and not "playonmac://" in url):
+            wx.MessageBox(_("You are trying to open a script design for {0}! It might not work as expected").format("PlayOnLinux or PlayOnBSD"), os.environ["APPLICATION_TITLE"])
+        if(os.environ["POL_OS"] == "Linux" and not "playonlinux://" in url):
+            wx.MessageBox(_("You are trying to open a script design for {0}! It might not work as expected").format("PlayOnMac or PlayOnBSD"), os.environ["APPLICATION_TITLE"])
+        if(os.environ["POL_OS"] == "FreeBSD" and not "playonbsd://" in url):
+            wx.MessageBox(_("You are trying to open a script design for {0}! It might not work as expected").format("PlayOnMac or PlayOnLinux"), os.environ["APPLICATION_TITLE"])
+            
         os.system("bash \"$PLAYONLINUX/bash/playonlinux-url_handler\" \""+url+"\" &")
 
     def MacReopenApp(self):
